@@ -247,16 +247,24 @@ def xonshconfig(env):
 @default_value
 def default_xonshrc(env):
     """Creates a new instance of the default xonshrc tuple."""
+    xcdrc = os.path.join(xonsh_config_dir(env), 'rc.xsh')
     if ON_WINDOWS:
         dxrc = (xonshconfig(env),
                 os.path.join(os_environ['ALLUSERSPROFILE'],
                              'xonsh', 'xonshrc'),
+                xcdrc,
                 os.path.expanduser('~/.xonshrc'))
     else:
-        dxrc = (xonshconfig(env), '/etc/xonshrc', os.path.expanduser('~/.xonshrc'))
+        dxrc = (xonshconfig(env), '/etc/xonshrc', xcdrc, os.path.expanduser('~/.xonshrc'))
     return dxrc
 
 
+@default_value
+def xonsh_append_newline(env):
+    """Appends a newline if we are in interactive mode"""
+    return env.get('XONSH_INTERACTIVE', False)
+
+
 # Default values should generally be immutable, that way if a user wants
 # to set them they have to do a copy and write them to the environment.
 # try to keep this sorted.
@@ -328,7 +336,7 @@ def DEFAULT_VALUES():
                                                          'share')),
         'XONSHCONFIG': xonshconfig,
         'XONSHRC': default_xonshrc,
-        'XONSH_APPEND_NEWLINE': False,
+        'XONSH_APPEND_NEWLINE': xonsh_append_newline,
         'XONSH_AUTOPAIR': False,
         'XONSH_CACHE_SCRIPTS': True,
         'XONSH_CACHE_EVERYTHING': False,
@@ -650,9 +658,9 @@ def DEFAULT_DOCS():
         'A list of the locations of run control files, if they exist.  User '
         'defined run control file will supersede values set in system-wide '
         'control file if there is a naming collision.', default=(
-            "On Linux & Mac OSX: ``['/etc/xonshrc', '~/.xonshrc']``\n"
+            "On Linux & Mac OSX: ``['/etc/xonshrc', '~/.config/xonsh/rc.xsh', '~/.xonshrc']``\n"
             "\nOn Windows: "
-            "``['%ALLUSERSPROFILE%\\\\xonsh\\\\xonshrc', '~/.xonshrc']``")),
+            "``['%ALLUSERSPROFILE%\\\\xonsh\\\\xonshrc', '~/.config/xonsh/rc.xsh', '~/.xonshrc']``")),
     'XONSH_APPEND_NEWLINE': VarDocs(
         'Append new line when a partial line is preserved in output.'
     ),
@@ -1205,6 +1213,9 @@ def default_env(env=None):
     ctx = dict(BASE_ENV)
     ctx.update(os_environ)
     ctx['PWD'] = _get_cwd() or ''
+    # These can cause problems for programs (#2543)
+    ctx.pop('LINES', None)
+    ctx.pop('COLUMNS', None)
     # other shells' PROMPT definitions generally don't work in XONSH:
     try:
         del ctx['PROMPT']
